@@ -174,7 +174,7 @@ void CertifyCertificateCommand::doStart()
                                             xi18nc("@info", "To certify other certificates, you first need to create an OpenPGP certificate for yourself.")
                                                 + QStringLiteral("<br><br>") + i18n("Do you wish to create one now?"),
                                             i18nc("@title:window", "Certification Not Possible"),
-                                            KGuiItem(i18n("Create")),
+                                            KGuiItem(i18nc("@action:button", "Create")),
                                             KStandardGuiItem::cancel());
         if (sel == KMessageBox::ButtonCode::PrimaryAction) {
             QEventLoop loop;
@@ -253,7 +253,7 @@ void CertifyCertificateCommand::Private::slotCertificationPrepared()
     userIdIndexes.reserve(selectedUserIds.size());
     for (unsigned int i = 0, numUserIds = target.numUserIDs(); i < numUserIds; ++i) {
         const auto userId = target.userID(i);
-        const bool userIdIsSelected = Kleo::any_of(selectedUserIds, [userId](const auto &uid) {
+        const bool userIdIsSelected = std::ranges::any_of(selectedUserIds, [userId](const auto &uid) {
             return Kleo::userIDsAreEqual(userId, uid);
         });
         if (userIdIsSelected) {
