@@ -28,12 +28,15 @@ class ExportPaperKeyCommand : public Command
 
 public:
     explicit ExportPaperKeyCommand(QAbstractItemView *view, KeyListController *parent);
+    explicit ExportPaperKeyCommand(const GpgME::Key &key);
 
     static Restrictions restrictions()
     {
-        return OnlyOneKey | NeedSecretKeyData | MustBeOpenPGP;
+        return OnlyOneKey | NeedSecretPrimaryKeyData | MustBeOpenPGP;
     }
 
+    bool success() const;
+
 private:
     class Private;
     inline Private *d_func();
