@@ -14,14 +14,14 @@
 
 #include "implementation_p.h"
 
-#include <gpgme++/global.h>
 #include <gpgme++/engineinfo.h>
 #include <gpgme++/error.h>
+#include <gpgme++/global.h>
 
 #include <gpg-error.h>
 
-#include <KLocalizedString>
 #include "kleopatra_debug.h"
+#include <KLocalizedString>
 
 #include <QGpgME/CryptoConfig>
 #include <QGpgME/Protocol>
@@ -36,20 +36,20 @@ using namespace GpgME;
 
 static QString engine_name(GpgME::Engine eng)
 {
-    static const char *engines[] = {
-        "gpg", "gpgsm", "gpgconf"
-    };
+    static const char *engines[] = {"gpg", "gpgsm", "gpgconf"};
     return QString::fromLatin1(engines[eng]);
 }
 
 static QString test_name(GpgME::Engine eng)
 {
-    static const char *names[] = {
-        I18NC_NOOP("@title", "GPG (OpenPGP Backend) installation"),
-        I18NC_NOOP("@title", "GpgSM (S/MIME Backend) installation"),
-        I18NC_NOOP("@title", "GpgConf (Configuration) installation"),
-    };
-    return i18nc("@title", names[eng]);
+    if (eng == GpgME::GpgEngine) {
+        return i18nc("@title", "GPG (OpenPGP Backend) installation");
+    } else if (eng == GpgME::GpgSMEngine) {
+        return i18nc("@title", "GpgSM (S/MIME Backend) installation");
+    } else if (eng == GpgME::GpgConfEngine) {
+        return i18nc("@title", "GpgConf (Configuration) installation");
+    }
+    return QStringLiteral("unknown");
 }
 
 namespace
@@ -91,16 +91,14 @@ public:
             return;
         }
 
-        m_explanation = xi18nc("@info",
-                                "<para>A problem was detected with the <application>%1</application> backend.</para>",
-                                engine_name(eng));
+        m_explanation = xi18nc("@info", "<para>A problem was detected with the <application>%1</application> backend.</para>", engine_name(eng));
 
         const EngineInfo ei = engineInfo(eng);
         if (ei.isNull()) {
             m_error = i18n("not supported");
             m_explanation += xi18nc("@info",
-                                     "<para>It seems that the <icode>gpgme</icode> library was compiled without "
-                                     "support for this backend.</para>");
+                                    "<para>It seems that the <icode>gpgme</icode> library was compiled without "
+                                    "support for this backend.</para>");
             m_proposedFix += xi18nc("@info",
                                     "<para>Replace the <icode>gpgme</icode> library with a version compiled "
                                     "with <application>%1</application> support.</para>",
@@ -110,22 +108,21 @@ public:
             // a fallback if the version could not be checked. We assume that it's not properly
             // installed in that case.
             m_error = i18n("not properly installed");
-            m_explanation += xi18nc("@info",
-                                     "<para>Backend <command>%1</command> is not installed properly.</para>", QFile::decodeName(ei.fileName()));
-            m_proposedFix += xi18nc("@info",
-                                    "<para>Please check the output of <command>%1 --version</command> manually.</para>",
-                                    QFile::decodeName(ei.fileName()));
+            m_explanation += xi18nc("@info", "<para>Backend <command>%1</command> is not installed properly.</para>", QFile::decodeName(ei.fileName()));
+            m_proposedFix +=
+                xi18nc("@info", "<para>Please check the output of <command>%1 --version</command> manually.</para>", QFile::decodeName(ei.fileName()));
         } else if (ei.fileName() && ei.version() && ei.requiredVersion()) {
             m_error = i18n("too old");
             m_explanation += xi18nc("@info",
-                                     "<para>Backend <command>%1</command> is installed in version %2, "
-                                     "but at least version %3 is required.</para>",
-                                     QFile::decodeName(ei.fileName()),
-                                     QString::fromUtf8(ei.version()),
-                                     QString::fromUtf8(ei.requiredVersion()));
+                                    "<para>Backend <command>%1</command> is installed in version %2, "
+                                    "but at least version %3 is required.</para>",
+                                    QFile::decodeName(ei.fileName()),
+                                    QString::fromUtf8(ei.version()),
+                                    QString::fromUtf8(ei.requiredVersion()));
             m_proposedFix += xi18nc("@info",
                                     "<para>Install <application>%1</application> version %2 or higher.</para>",
-                                    engine_name(eng), QString::fromUtf8(ei.requiredVersion()));
+                                    engine_name(eng),
+                                    QString::fromUtf8(ei.requiredVersion()));
         } else {
             m_error = m_explanation = i18n("unknown problem");
             m_proposedFix += xi18nc("@info",
@@ -134,7 +131,6 @@ public:
                                     engine_name(eng));
         }
     }
-
 };
 }
 
@@ -173,21 +169,24 @@ bool SelfTestImplementation::ensureEngineVersion(GpgME::Engine engine, int major
     if (!err && version) {
         // properly installed, but too old
         m_explanation = xi18nc("@info",
-                                "<para><application>%1</application> v%2.%3.%4 is required for this test, but only %5 is installed.</para>",
-                                engine_name(engine), major, minor, patch, QString::fromUtf8(version));
+                               "<para><application>%1</application> v%2.%3.%4 is required for this test, but only %5 is installed.</para>",
+                               engine_name(engine),
+                               major,
+                               minor,
+                               patch,
+                               QString::fromUtf8(version));
         m_proposedFix += xi18nc("@info",
                                 "<para>Install <application>%1</application> version %2 or higher.</para>",
-                                engine_name(engine), QStringLiteral("%1.%2.%3").arg(major).arg(minor).arg(patch));
+                                engine_name(engine),
+                                QStringLiteral("%1.%2.%3").arg(major).arg(minor).arg(patch));
     } else {
         // not properly installed
         m_explanation = xi18nc("@info",
-                                "<para><application>%1</application> is required for this test, but does not seem available.</para>"
-                                "<para>See tests further up for more information.</para>",
-                                engine_name(engine));
-        m_proposedFix = xi18nc("@info %1: test name",
-                               "<para>See \"%1\" above.</para>", test_name(engine));
+                               "<para><application>%1</application> is required for this test, but does not seem available.</para>"
+                               "<para>See tests further up for more information.</para>",
+                               engine_name(engine));
+        m_proposedFix = xi18nc("@info %1: test name", "<para>See \"%1\" above.</para>", test_name(engine));
     }
 
     return false;
 }
-
