@@ -18,7 +18,7 @@ struct AlgorithmInfo;
 struct KeyPairInfo;
 
 /** Class to work with PIV smartcards or compatible tokens */
-class PIVCard: public Card
+class PIVCard : public Card
 {
 public:
     explicit PIVCard(const Card &card);
@@ -33,13 +33,9 @@ public:
     static std::string pinKeyRef();
     static std::string pukKeyRef();
 
-    static const std::vector<KeyPairInfo> & supportedKeys();
+    static const std::vector<KeyPairInfo> &supportedKeys();
     static QString keyDisplayName(const std::string &keyRef);
     static std::vector<AlgorithmInfo> supportedAlgorithms(const std::string &keyRef);
-
-    std::string certificateData(const std::string &keyRef) const;
-    void setCertificateData(const std::string &keyRef, const std::string &data);
 };
 } // namespace Smartcard
 } // namespace Kleopatra
-
