@@ -10,9 +10,9 @@
 */
 #pragma once
 
-#include "commands/changepincommand.h"
+#include "smartcardwidget.h"
 
-#include <QWidget>
+#include "commands/changepincommand.h"
 
 #include <gpgme++/error.h>
 
@@ -32,7 +32,7 @@ struct KeyPairInfo;
 class OpenPGPCard;
 } // namespace SmartCard
 
-class PGPCardWidget : public QWidget
+class PGPCardWidget : public SmartCardWidget
 {
     Q_OBJECT
 public:
@@ -48,7 +48,6 @@ public Q_SLOTS:
     void changeNameResult(const GpgME::Error &err);
     void changeUrlRequested();
     void changeUrlResult(const GpgME::Error &err);
-    void createKeyFromCardKeys();
     void createCSR(const std::string &keyref);
     void generateKey(const std::string &keyref);
 
@@ -56,15 +55,14 @@ private:
     void doChangePin(const std::string &keyRef, Commands::ChangePinCommand::ChangePinMode mode = Commands::ChangePinCommand::NormalMode);
 
 private:
-    QLabel *mSerialNumber = nullptr;
     QLabel *mCardHolderLabel = nullptr;
-    QLabel *mVersionLabel = nullptr;
     QLabel *mUrlLabel = nullptr;
-    QPushButton *mKeyForCardKeysButton = nullptr;
+    QLabel *mPinCounterLabel = nullptr;
+    QPushButton *mSetOrChangePUKButton = nullptr;
     OpenPGPKeyCardWidget *mKeysWidget = nullptr;
     QString mUrl;
     bool mCardIsEmpty = false;
     bool mIs21 = false;
-    std::string mRealSerial;
+    bool mPUKIsAvailable = false;
 };
 } // namespace Kleo
