@@ -108,7 +108,7 @@ private:
         }
         const auto filter = KeyFilterManager::instance()->keyFilterByID(notCertifiedKeysFilterId());
         if (filter) {
-            if (Kleo::any_of(KeyCache::instance()->keys(), [filter](const auto &key) {
+            if (std::ranges::any_of(KeyCache::instance()->keys(), [filter](const auto &key) {
                     return filter->matches(key, KeyFilter::Filtering);
                 })) {
                 certifyButton->show();
@@ -134,13 +134,13 @@ SearchBar::Private::Private(SearchBar *qq)
     layout->setContentsMargins(0, 0, 0, 0);
     lineEdit = new QLineEdit(q);
     lineEdit->setClearButtonEnabled(true);
-    lineEdit->setPlaceholderText(i18n("Search..."));
+    lineEdit->setPlaceholderText(i18nc("@info:placeholder", "Enter search term"));
     lineEdit->setAccessibleName(i18n("Filter certificates by text"));
-    lineEdit->setToolTip(i18n("Show only certificates that match the entered search term."));
+    lineEdit->setToolTip(i18nc("@info:tooltip", "Show only certificates that match the entered search term."));
     layout->addWidget(lineEdit, /*stretch=*/1);
     combo = new QComboBox(q);
     combo->setAccessibleName(i18n("Filter certificates by category"));
-    combo->setToolTip(i18n("Show only certificates that belong to the selected category."));
+    combo->setToolTip(i18nc("@info:tooltip", "Show only certificates that belong to the selected category."));
     layout->addWidget(combo);
     certifyButton = new QPushButton(q);
     certifyButton->setIcon(QIcon::fromTheme(QStringLiteral("security-medium")));
@@ -159,10 +159,10 @@ SearchBar::Private::Private(SearchBar *qq)
     proxyModel->sort(0, Qt::AscendingOrder);
     combo->setModel(proxyModel);
 
-    KDAB_SET_OBJECT_NAME(layout);
-    KDAB_SET_OBJECT_NAME(lineEdit);
-    KDAB_SET_OBJECT_NAME(combo);
-    KDAB_SET_OBJECT_NAME(certifyButton);
+    Q_SET_OBJECT_NAME(layout);
+    Q_SET_OBJECT_NAME(lineEdit);
+    Q_SET_OBJECT_NAME(combo);
+    Q_SET_OBJECT_NAME(certifyButton);
 
     connect(lineEdit, &QLineEdit::textChanged, q, &SearchBar::stringFilterChanged);
     connect(combo, &QComboBox::currentIndexChanged, q, [this](int index) {
@@ -194,7 +194,7 @@ SearchBar::~SearchBar()
 
 void SearchBar::updateClickMessage(const QString &shortcutStr)
 {
-    d->lineEdit->setPlaceholderText(i18n("Search...<%1>", shortcutStr));
+    d->lineEdit->setPlaceholderText(i18nc("@info:placeholder", "Enter search term <%1>", shortcutStr));
 }
 
 // slot
